Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2011-12-04 22:39:19 +0400
committerCampbell Barton <ideasman42@gmail.com>2011-12-04 22:39:19 +0400
commit22a1ad61f93a4b060500e5295c58b128f24a2daf (patch)
tree5693c7acd41e5d325cf3f6f1675cbceb232dd8a4 /source/blender/makesdna/DNA_key_types.h
parenta115c02605b2692710f5d9b64d87407b7ca5b374 (diff)
parent937c5494c4933c65635450e66aeacffed74939f2 (diff)
svn merge ^/trunk/blender -r42372:42416
Diffstat (limited to 'source/blender/makesdna/DNA_key_types.h')
-rw-r--r--source/blender/makesdna/DNA_key_types.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/makesdna/DNA_key_types.h b/source/blender/makesdna/DNA_key_types.h
index f8b48a2c60f..ee5cf96f110 100644
--- a/source/blender/makesdna/DNA_key_types.h
+++ b/source/blender/makesdna/DNA_key_types.h
@@ -31,6 +31,7 @@
* \ingroup DNA
*/
+#include "DNA_defs.h"
#include "DNA_listBase.h"
#include "DNA_ID.h"
@@ -64,10 +65,10 @@ typedef struct Key {
KeyBlock *refkey;
char elemstr[32];
int elemsize;
- float curval;
+ float curval DNA_DEPRECATED;
ListBase block;
- struct Ipo *ipo; // XXX depreceated... old animation system
+ struct Ipo *ipo DNA_DEPRECATED; /* old animation system, deprecated for 2.5 */
ID *from;
@@ -98,4 +99,3 @@ typedef struct Key {
#define KEYBLOCK_LOCKED (1<<2)
#define KEYBLOCK_MISSING (1<<3) /*temporary flag*/
#endif
-